use fantoccini::{elements::Element, ClientBuilder, Locator};

#[derive(Debug, Clone)]
struct Answer {
    upvotes: u32,
    author: String,
    content: String,
}

// let's set up the sequence of steps we want the browser to take
async fn get_answer() -> anyhow::Result<Answer> {
    let c = ClientBuilder::native()
        .connect("http://localhost:4444")
        .await
        .expect("failed to connect to WebDriver");

    // first, go to the Wikipedia page for Foobar
    c.goto("https://stackoverflow.com/questions/11227809/why-is-processing-a-sorted-array-faster-than-processing-an-unsorted-array").await?;

    let answer_loc = c.find(Locator::Css(".answer")).await;
    let text = answer_loc.unwrap().text().await.unwrap();

    let score = text
        .clone()
        .split('\n')
        .collect::<Vec<&str>>()
        .get(0)
        .unwrap()
        .parse::<u32>()?;
    let content = text;

    c.close().await.unwrap();

    Ok(Answer {
        upvotes: score,
        content,
        author: "unimplemented".to_string(),
    })
}

#[tokio::main]
async fn main() {
    dbg!(get_answer().await);
}
